@@ -22,7 +22,6 @@ class _Regressor(object):
     """
     Regressor base class
     """
-    time_it = False
 
     def __init__(self,
                  data=None,
@@ -53,10 +52,6 @@ class _Regressor(object):
         else:
             self.coefficient = None
 
-        if kwargs is not None:
-            if 'timer' in kwargs:
-                _Regressor.time_it = kwargs['timer']
-
     def __repr__(self):
         return "<Regressor base class>"
 
@@ -239,7 +234,7 @@ class _Regressor(object):
         return defaults
 
     @staticmethod
-    @Timer.timing(time_it)
+    @Timer.timing
     def regress_raster(regressor,
                        raster_obj,
                        outfile=None,
@@ -448,7 +443,7 @@ class _Regressor(object):
         return out_dict
 
     @staticmethod
-    @Timer.timing(True)
+    @Timer.timing
     def fit_regressor(args_list,
                       rank=None):
         """
@@ -488,7 +483,6 @@ class _Regressor(object):
 
             # initialize RF classifier
             model = RFRegressor(**param)
-            model.time_it = True
 
             regress_limit = [defaults['ulim_lower_multiplier'] * ulim,
                              defaults['ulim_upper_multiplier'] * ulim]
@@ -561,8 +555,6 @@ class MRegressor(_Regressor):
     This uses scikit-learn multiple regressor library
     """
 
-    time_it = False
-
     def __init__(self,
                  data=None,
                  regressor=None,
@@ -582,10 +574,6 @@ class MRegressor(_Regressor):
         self.intercept = self.regressor.intercept_ if hasattr(self.regressor, 'intercept_') else None
         self.coefficient = self.regressor.coef_ if hasattr(self.regressor, 'coef_') else None
 
-        if kwargs is not None:
-            if 'timer' in kwargs:
-                MRegressor.time_it = kwargs['timer']
-
     def __repr__(self):
         # gather which attributes exist
         attr_truth = [self.coefficient is not None,
@@ -612,7 +600,7 @@ class MRegressor(_Regressor):
             # if empty return empty
             return "<Multiple Linear Regressor: __empty__>"
 
-    @Timer.timing(time_it)
+    @Timer.timing
     def predict(self,
                 arr,
                 ntile_max=5,
@@ -825,8 +813,6 @@ class RFRegressor(_Regressor):
     """Random Forest Regressor.
      This uses scikit-learn Random Forest regressor"""
 
-    time_it = False
-
     def __init__(self,
                  data=None,
                  regressor=None,
@@ -872,10 +858,6 @@ class RFRegressor(_Regressor):
 
         self.dec_paths = list()
 
-        if kwargs is not None:
-            if 'timer' in kwargs:
-                MRegressor.time_it = kwargs['timer']
-
     def __repr__(self):
         # gather which attributes exist
         attr_truth = [hasattr(self.regressor, 'estimators_'),
@@ -1195,7 +1177,7 @@ class RFRegressor(_Regressor):
         else:
             return
 
-    @Timer.timing(time_it)
+    @Timer.timing
     def predict(self,
                 arr,
                 output_type=None,
@@ -1589,8 +1571,6 @@ class HRFRegressor(RFRegressor):
     (based on hierarchical regression of available features)
     """
 
-    time_it = False
-
     def __init__(self,
                  data=None,
                  regressor=None,
@@ -1632,7 +1612,7 @@ class HRFRegressor(RFRegressor):
             "\n---\nRegressors: \n---\n{}".format('\n'.join(repr_regressor)) + \
             "\n---\n\n"
 
-    @Timer.timing(time_it)
+    @Timer.timing
     def regress_raster(self,
                        raster_obj,
                        outfile=None,
